@@ -26,6 +26,7 @@ typedef struct FormData_cron_job
 	int nodePort;
 	text database;
 	text userName;
+	bool active;
 #endif
 } FormData_cron_job;
 
@@ -40,7 +41,7 @@ typedef FormData_cron_job *Form_cron_job;
  *      compiler constants for cron_job
  * ----------------
  */
-#define Natts_cron_job 7
+#define Natts_cron_job 8
 #define Anum_cron_job_jobid 1
 #define Anum_cron_job_schedule 2
 #define Anum_cron_job_command 3
@@ -48,6 +49,7 @@ typedef FormData_cron_job *Form_cron_job;
 #define Anum_cron_job_nodeport 5
 #define Anum_cron_job_database 6
 #define Anum_cron_job_username 7
+#define Anum_cron_job_active 8
 
 
 #endif /* CRON_JOB_H */
