@@ -130,6 +130,11 @@ _PG_init(void)
 {
 	BackgroundWorker worker;
 
+	if (IsBinaryUpgrade)
+	{
+		return;
+	}
+
 	if (!process_shared_preload_libraries_in_progress)
 	{
 		ereport(ERROR, (errmsg("pg_cron can only be loaded via shared_preload_libraries"),
@@ -181,7 +186,10 @@ _PG_init(void)
 	worker.bgw_notify_pid = 0;
 	sprintf(worker.bgw_library_name, "pg_cron");
 	sprintf(worker.bgw_function_name, "PgCronWorkerMain");
-	snprintf(worker.bgw_name, BGW_MAXLEN, "pg_cron_scheduler");
+	snprintf(worker.bgw_name, BGW_MAXLEN, "pg_cron scheduler");
+#if (PG_VERSION_NUM >= 110000)
+	snprintf(worker.bgw_type, BGW_MAXLEN, "pg_cron scheduler");
+#endif
 
 	RegisterBackgroundWorker(&worker);
 }
@@ -239,7 +247,14 @@ PgCronWorkerMain(Datum arg)
 	BackgroundWorkerUnblockSignals();
 
 	/* Connect to our database */
+#if (PG_VERSION_NUM < 110000)
 	BackgroundWorkerInitializeConnection(CronTableDatabaseName, NULL);
+#else
+	BackgroundWorkerInitializeConnection(CronTableDatabaseName, NULL, 0);
+#endif
+
+	/* Make pg_cron recognisable in pg_stat_activity */
+	pgstat_report_appname("pg_cron scheduler");
 
 	/* Determine how many tasks we can run concurrently */
 	if (MaxConnections < MaxRunningTasks)
@@ -263,12 +278,12 @@ PgCronWorkerMain(Datum arg)
 		MaxRunningTasks = 1;
 	}
 
-	CronLoopContext = AllocSetContextCreate(CurrentMemoryContext,
-											"pg_cron loop context",
-											ALLOCSET_DEFAULT_MINSIZE,
-											ALLOCSET_DEFAULT_INITSIZE,
-											ALLOCSET_DEFAULT_MAXSIZE);
 
+	CronLoopContext = PgAllocSetContextCreate(CurrentMemoryContext,
+											  "pg_cron loop context",
+											  ALLOCSET_DEFAULT_MINSIZE,
+											  ALLOCSET_DEFAULT_INITSIZE,
+											  ALLOCSET_DEFAULT_MAXSIZE);
 	InitializeJobMetadataCache();
 	InitializeTaskStateHash();
 
@@ -912,7 +927,7 @@ ManageCronTask(CronTask *task, TimestampTz currentTime)
 			{
 				char *command = cronJob->command;
 
-				ereport(LOG, (errmsg("cron job %ld starting: %s",
+				ereport(LOG, (errmsg("cron job " INT64_FORMAT " starting: %s",
 									 jobId, command)));
 			}
 
@@ -1119,7 +1134,7 @@ ManageCronTask(CronTask *task, TimestampTz currentTime)
 							char *cmdStatus = PQcmdStatus(result);
 							char *cmdTuples = PQcmdTuples(result);
 
-							ereport(LOG, (errmsg("cron job %ld completed: %s %s",
+							ereport(LOG, (errmsg("cron job " INT64_FORMAT " completed: %s %s",
 												 jobId, cmdStatus, cmdTuples)));
 						}
 
@@ -1165,7 +1180,7 @@ ManageCronTask(CronTask *task, TimestampTz currentTime)
 							char *rowString = ngettext("row", "rows",
 													   tupleCount);
 
-							ereport(LOG, (errmsg("cron job %ld completed: "
+							ereport(LOG, (errmsg("cron job " INT64_FORMAT " completed: "
 												 "%d %s",
 												 jobId, tupleCount,
 												 rowString)));
@@ -1206,7 +1221,7 @@ ManageCronTask(CronTask *task, TimestampTz currentTime)
 
 			if (task->errorMessage != NULL)
 			{
-				ereport(LOG, (errmsg("cron job %ld %s",
+				ereport(LOG, (errmsg("cron job " INT64_FORMAT " %s",
 									 jobId, task->errorMessage)));
 
 				if (task->freeErrorMessage)
@@ -1216,7 +1231,7 @@ ManageCronTask(CronTask *task, TimestampTz currentTime)
 			}
 			else
 			{
-				ereport(LOG, (errmsg("cron job %ld failed", jobId)));
+				ereport(LOG, (errmsg("cron job " INT64_FORMAT " failed", jobId)));
 			}
 
 			task->startDeadline = 0;
